@@ -49,6 +49,7 @@ class WorkerClient:
     path = None
     new_refcount = 0
     init_refcount = 0
+    config_path = CURRENTPATH + "/configs/default.json"
 
     def __new__(cls, path=None, config=None):
         if not hasattr(cls, '_instance'):
@@ -63,12 +64,11 @@ class WorkerClient:
             self.path = path
         if self.path is None:
             raise Exception("path is not None")
-        if not config:
-            const.read_config(
-                CURRENTPATH + "/configs/default.json"
-            )
-        else:
-            const.read_config(config)
+        if config:
+            self.config_path = config
+            const.read_config(self.config_path)
+        if not HEADER_PROTOCOL:
+            const.read_config(self.config_path)
 
     def _processing_data(self, mtype: str, data):
         '''将传入的数据转为服务端可读取的数据'''
@@ -121,7 +121,7 @@ class WorkerClient:
 
 
 # async def async_main():
-#     m = WorkerClient("../unix_sock.sock")
+#     m = WorkerClient("../unix_sock.sock", config="../default.json")
 #     c = WorkerClient()
 #     await m.create_conn() # 建立一个连接
 #     await m.send_msg("O", "你好")
