@@ -1,4 +1,5 @@
 import asyncio
+import os
 from inspect import isfunction
 from deepfos_ipc_protocol.utils import (
     resolve_header_protocol,
@@ -12,6 +13,7 @@ from configs import const
 HEADER_PROTOCOL = const.HEADER_PROTOCOL
 MESSAGE_PROTOCOL = const.MESSAGE_PROTOCOL
 DETAILLIST_PROTOCOL = const.DETAILLIST_PROTOCOL
+CURRENTPATH = os.path.dirname(__file__)
 
 
 logger = logging.getLogger(__name__)
@@ -73,7 +75,9 @@ class MasterServer:
         self.func = self.get_func()
         self.waiter = None
         if not config:
-            const.read_config("./configs/default.json")
+            const.read_config(
+                CURRENTPATH + "/configs/default.json"
+            )
         else:
             const.read_config(config)
 
@@ -105,7 +109,7 @@ class MasterServer:
         logger.info('Master Server stop complete.')
 
 # async def run():
-#     m = MasterServer("../unix_sock.sock", config="/Users/chenxingyu/Desktop/fenghe/deepfos-ipc-protocol/aaa.json")
+#     m = MasterServer("../unix_sock.sock")
 #     await m.task()
 
 # asyncio.run(run())
